function SBVAR = SetupSBVAR_ConjugatePrior(n_lags, nu, Phi, Psi, Omega_inv, nu_bar, Phi_bar, Psi_bar, Omega_bar_inv, Y, X, U, V)
%
% The fields available are:
%
%  prior  - 'Conjugate'
%  n_lags - number of lags
%  n  - number endogenous variables
%  m  - number predetermined variables
%  T  - number observations
%  Y  - endogenous data
%  X  - predetermined data
%  YY - Y'*Y
%  XX - X'*X
%  XY - X'*Y
%  nu_bar            - generalized Gaussian prior parameter
%  Phi_bar_inv       - generalized Gaussian prior parameter
%  mu_bar            - matrix Gaussian prior parameter
%  Omega_bar_inv     - matrix Gaussian prior parameter
%  nu_tilde          - generalized Gaussian posterior parameter
%  Phi_tilde_inv     - generalized Gaussian posterior parameter
%  mu_tilde          - matrix Gaussian posterior parameter
%  Omega_tilde_inv   - matrix Gaussian posterior parameter
%  U - default value: identity     A0*e(j) = U{j}*b(j)
%  V - default value: identity     Aplus*e{j} = V{j}*g(j) + W{j}*b(j)
%  UT    - T
%  VR
%  PUp
%  TiUP

% prior type
SBVAR.prior = 'Conjugate';

% sizes
SBVAR.n_lags = n_lags;
SBVAR.ntilde = size(Y,2);
SBVAR.mtilde = size(X,2);
SBVAR.T      = size(Y,1);


% unrestricted prior
SBVAR.nu        = nu;
SBVAR.Phi       = Phi;
SBVAR.Psi       = Psi;
SBVAR.Omega_inv = Omega_inv;

% unrestricted posterior
[SBVAR.nu_tilde, SBVAR.Phi_tilde, SBVAR.Psi_tilde, SBVAR.Omega_tilde_inv] = SBVAR_PosteriorParameters(SBVAR.nu, SBVAR.Phi, SBVAR.Psi, SBVAR.Omega_inv, Y, X);


% unrestricted proposal prior
SBVAR.nu_bar        = nu_bar;
SBVAR.Phi_bar       = Phi_bar;
SBVAR.Psi_bar       = Psi_bar;
SBVAR.Omega_bar_inv = Omega_bar_inv;

% unrestricted proposal posterior 
[SBVAR.nu_hat, SBVAR.Phi_hat, SBVAR.Psi_hat, SBVAR.Omega_hat_inv] = SBVAR_PosteriorParameters(SBVAR.nu_bar, SBVAR.Phi_bar, SBVAR.Psi_bar, SBVAR.Omega_bar_inv, Y, X);

% restrictions
SBVAR.U = U;
SBVAR.V = V;

SBVAR.nubar      = nu_bar;
SBVAR.Hjbar      = cell(SBVAR.ntilde,1);
SBVAR.Pjbar      = cell(SBVAR.ntilde,1);
SBVAR.Sjbar_inv  = cell(SBVAR.ntilde,1);


for j=1:SBVAR.ntilde
    
    SBVAR.Hjbar{j}     =  eye(SBVAR.mtilde)/Omega_bar_inv(1+(j-1)*SBVAR.mtilde:SBVAR.mtilde*j,1+(j-1)*SBVAR.mtilde:SBVAR.mtilde*j);
    SBVAR.Pjbar{j}     =  Psi_bar(1+(j-1)*SBVAR.mtilde:SBVAR.mtilde*j,1+(j-1)*SBVAR.ntilde:SBVAR.ntilde*j);
    SBVAR.Sjbar_inv{j} =  Phi_bar(1+(j-1)*SBVAR.ntilde:SBVAR.ntilde*j,1+(j-1)*SBVAR.ntilde:SBVAR.ntilde*j);
    
end


% restricted prior
SBVAR.Hjtilde      = cell(SBVAR.ntilde,1);
SBVAR.Pjtilde      = cell(SBVAR.ntilde,1);
SBVAR.Sjtilde_inv  = cell(SBVAR.ntilde,1);


for j=1:SBVAR.ntilde
 
    SBVAR.Hjtilde{j}     = inv(V{j}'*(SBVAR.Hjbar{j}\V{j}));
    SBVAR.Pjtilde{j}     = SBVAR.Hjtilde{j}*V{j}'*(SBVAR.Hjbar{j}\SBVAR.Pjbar{j})*U{j}; 
    SBVAR.Sjtilde_inv{j} = U{j}'*SBVAR.Sjbar_inv{j}*U{j} + U{j}'*SBVAR.Pjbar{j}'*(SBVAR.Hjbar{j}\SBVAR.Pjbar{j})*U{j} - SBVAR.Pjtilde{j}'*(SBVAR.Hjtilde{j}\SBVAR.Pjtilde{j});

end


% restricted posterior
SBVAR.nuhat      = SBVAR.T + nu_bar;
SBVAR.Hjhat      = cell(SBVAR.ntilde,1);
SBVAR.Pjhat      = cell(SBVAR.ntilde,1);
SBVAR.Sjhat      = cell(SBVAR.ntilde,1);


% restricted lower dimensional posterior
SBVAR.Hjbghat      = cell(SBVAR.ntilde,1);
SBVAR.Pjbghat      = cell(SBVAR.ntilde,1);
SBVAR.Sjbghat      = cell(SBVAR.ntilde,1);
SBVAR.UThat        = cell(SBVAR.ntilde,1);
SBVAR.TihatUp      = cell(SBVAR.ntilde,1);

SBVAR.dimSbg       = cell(SBVAR.ntilde,1);


for j=1:SBVAR.ntilde
  
    
    SBVAR.Hjbghat{j} = eye(size(V{j},2))/(V{j}'*(X'*X)*V{j} + inv(SBVAR.Hjtilde{j}));
    SBVAR.Pjbghat{j} = SBVAR.Hjbghat{j}*(V{j}'*(X'*Y)*U{j}  + SBVAR.Hjtilde{j}\SBVAR.Pjtilde{j});
    
    SBVAR.Sjbghat{j} = eye(size(U{j},2))/(U{j}'*(Y'*Y)*U{j} + SBVAR.Sjtilde_inv{j} + SBVAR.Pjtilde{j}'*(SBVAR.Hjtilde{j}\SBVAR.Pjtilde{j}) - SBVAR.Pjbghat{j}'*(SBVAR.Hjbghat{j}\SBVAR.Pjbghat{j}));
    
    
    SBVAR.Hjhat{j}   = V{j}*SBVAR.Hjbghat{j}*V{j}';
    SBVAR.Pjhat{j}   = V{j}*SBVAR.Pjbghat{j}*U{j}'; 
    SBVAR.Sjhat{j}   = U{j}*SBVAR.Sjbghat{j}*U{j}';


    SBVAR.That       = chol(0.5*(SBVAR.Sjbghat{j}+SBVAR.Sjbghat{j}'))'; 

    SBVAR.UThat{j}   = U{j}*SBVAR.That;   
    SBVAR.TihatUp{j} = SBVAR.That\(U{j}');
    
    SBVAR.dimSbg{j} = size(SBVAR.Sjbghat{j},1);

end

