%-----------------------------------------------
%	  Three-country Life Cycle
%       
%  A: US (Dependency ratio: 0.211), 
%  B: Young Country (Dependency ratio: 0.2)
%  C: Old Country (Dependency ratio: 0.28)
%  One period is a quarter
%-----------------------------------------------

close all;

%-----------------------------------
%	ENDOGENOUS VARIABLES
%-----------------------------------

var 

% interest rates, prices, inflation, exchange rate, marginal cost
RA RB RC wA wB wC eB eC paA paB paC pbA pbB pbC pcA pcB pcC 
infA infB infC RnA RnB RnC mcA mcB mcC infpA infpB infpC pFA pFB pFC dFA 
dFB dFC QA QB QC

% marginal propensities to consume
epsA epsB epsC xiwA xiwB xiwC xirA xirB xirC bigomA bigomB bigomC

% distribution of wealth
lamA lamB lamC

% aggregate quantities
cA cB cC aA aB aC invA invB invC yAA yBB yCC kA kB kC cAA cAB cAC
cBA cBB cBC cCA cCB cCC lA lB lC expA expB expC impA impB impC
imppA imppB imppC

% group quantities
crA crB crC cwA cwB cwC arA arB arC awA awB awC hrA hrB hrC hwA hwB hwC
lrA lrB lrC lwA lwB lwC 

% fiscal variables
fA fB fC aggiA aggiB aggiC riA riB riC wiA wiB wiC;

%-----------------------------------
%	EXOGENOUS VARIABLES
%-----------------------------------

varexo e_mA e_mB e_mC;

%-----------------------------------
%	PARAMETERS
%-----------------------------------

parameters

% technology and preferences
alpha betaA betaB betaC delta omega sigma nu rho phipA phipB phipC    

% productivity, fiscal ratios and monetary policy
x rhoi pipi piy zeta

% steady state life expectancy
gammaA gammaB gammaC n 

% demographis
psiA psiB psiC

% sticky price
kappa gammap

% final goods producers
phi eta

% Steady state values
RAss RBss RCss RnAss RnBss RnCss bigomAss bigomBss bigomCss lAss lBss lCss
lrAss lrBss lrCss yk kl yl mcAss mcBss mcCss wAss wBss wCss kAss kBss kCss
yAAss yBBss yCCss invAss invBss invCss cAss cBss cCss pFAss pFBss pFCss 
dFAss dFBss dFCss aAss aBss aCss cAAss cABss cACss cBAss cBBss cBCss cCAss
cCBss cCCss xirAss xirBss xirCss xiwAss xiwBss xiwCss epsAss epsBss epsCss
lwAss lwBss lwCss hrAss hrBss hrCss hwAss hwBss hwCss lamAss lamBss lamCss
arAss arBss arCss awAss awBss awCss crAss crBss crCss cwAss cwBss cwCss;

%-----------------------------------
%	CALIBRATION
%-----------------------------------

psiA     = 0.211;                                                          % 1970-2015 US
psiB     = 0.20;                                                           % average of young countries
psiC     = 0.28;                                                           % average of old countries

phi        = (1-0.5665/0.7665);

betaA      = 0.992873457099265;
betaB      = 0.993395550993387;  
betaC      = 0.990554856474844;  

bigomAss   = 1.018352833528335;
bigomBss   = 1.019063570635706; 
bigomCss   = 1.015209162091621;

lAss       = 0.395901979204752;
lBss       = lAss;
lCss       = lAss;
lrAss      = 0.016839708397084; 
lrBss      = 0.016141581128004;
lrCss      = 0.020932809328093;

phipA      = 0.7;

x        = 1;
n        = 1.008^0.25;                                                     % average population growht rate from UN for 1970 - 2020
omega      = 1-1/(4*45);
gammaA     = n-(1-omega)/psiA;                                           
gammaB     = n-(1-omega)/psiB;
gammaC     = n-(1-omega)/psiC;

delta      = 0.025;
alpha      = 0.334;
sigma      = 0.5;
nu         = 0.4;
rho        = (sigma - 1) / sigma;
kappa      = 11;
eta        = 0.9;
gammap     = 0.75*(kappa-1)/(1-0.75)/(1-0.75*(betaA+betaB+betaC)/3);
rhoi       = 0.5;
pipi       = 1.2;
piy        = 0;
zeta       = 2.5;

RAss       = 1.0101;
RBss       = RAss;
RCss       = RAss;
RnAss      = RAss;
RnBss      = RnAss;
RnCss      = RnAss;

yk         = (RAss-1+delta)/((kappa - 1) / kappa)/alpha;
kl         = yk^(1/(alpha-1));
yl         = yk*kl;

mcAss      = (kappa - 1) / kappa; 
mcBss      = mcAss;
mcCss      = mcAss;

wAss       = mcAss*(1-alpha)*yl;
wBss       = wAss;
wCss       = wAss;

kAss       = kl*lAss;
yAAss      = yk*kAss;
invAss     = (n*x-1+delta)*kAss;
dFAss      = (1-mcAss)*yAAss;
pFAss      = dFAss*x*n/(RAss-x*n);
cAss       = yAAss - invAss;
kBss       = kl*lBss;
yBBss      = yk*kBss;
invBss     = (n*x-1+delta)*kBss;
dFBss      = (1-mcBss)*yBBss;
pFBss      = dFBss*x*n/(RBss-x*n);
cBss       = yBBss - invBss;
kCss       = kl*lCss;
yCCss      = yk*kCss;
invCss     = (n*x-1+delta)*kCss;
dFCss      = (1-mcCss)*yCCss;
pFCss      = dFCss*x*n/(RCss-x*n);
cCss       = yCCss - invCss;
phipB      = (lBss-1+(1-nu)*cBss/nu/wBss)/psiB;
phipC      = (lCss-1+(1-nu)*cCss/nu/wCss)/psiC;
cAAss      = (1-phi)*cAss;
cBAss      = 0.5*phi*cAss;
cCAss      = 0.5*phi*cAss;
cABss      = cBAss;
cCBss      = cABss;
cBBss      = cBss-cABss-cCBss;
cACss      = cCAss;
cBCss      = cCBss;
cCCss      = cCss - cACss - cBCss;
aAss       = kAss + pFAss;
aBss       = kBss + pFBss;
aCss       = kCss + pFCss;

xirAss    = 1 - gammaA * (betaA ^ sigma) * (RAss ^ (sigma - 1)) * ((1/x)^(sigma*rho*(1-nu)));
xirBss    = 1 - gammaB * (betaB ^ sigma) * (RBss ^ (sigma - 1)) * ((1/x)^(sigma*rho*(1-nu)));
xirCss    = 1 - gammaC * (betaC ^ sigma) * (RCss ^ (sigma - 1)) * ((1/x)^(sigma*rho*(1-nu)));
xiwAss    = 1 - (betaA ^ sigma) * ((bigomAss*RAss) ^ (sigma - 1))* ((1/x)^(sigma*rho*(1-nu)));
xiwBss    = 1 - (betaB ^ sigma) * ((bigomBss*RBss) ^ (sigma - 1))* ((1/x)^(sigma*rho*(1-nu)));
xiwCss    = 1 - (betaC ^ sigma) * ((bigomCss*RCss) ^ (sigma - 1))* ((1/x)^(sigma*rho*(1-nu)));
epsAss    = xirAss / xiwAss;
epsBss    = xirBss / xiwBss;
epsCss    = xirCss / xiwCss;
lwAss     = (lAss-phipA*lrAss);
lwBss     = (lBss-phipB*lrBss);
lwCss     = (lCss-phipC*lrCss);
hrAss     = wAss*phipA*lrAss/(1-gammaA*x/RAss);
hrBss     = wBss*phipB*lrBss/(1-gammaB*x/RBss);
hrCss     = wCss*phipC*lrCss/(1-gammaC*x/RCss);
hwAss     = (wAss*lwAss + (phipA^(nu-1))*(epsAss^(1/(1-sigma)))*x*(1-omega)*hrAss/RAss/psiA/bigomAss)/(1-omega*x/bigomAss/RAss);
hwBss     = (wBss*lwBss + (phipB^(nu-1))*(epsBss^(1/(1-sigma)))*x*(1-omega)*hrBss/RBss/psiB/bigomBss)/(1-omega*x/bigomBss/RBss);
hwCss     = (wCss*lwCss + (phipC^(nu-1))*(epsCss^(1/(1-sigma)))*x*(1-omega)*hrCss/RCss/psiC/bigomCss)/(1-omega*x/bigomCss/RCss);
lamAss    = (x*n*(1-omega)*aAss/omega-xirAss*hrAss+wAss*phipA*lrAss)/(x*n*aAss/omega-(1-xirAss)*RAss*aAss);
lamBss    = (x*n*(1-omega)*aBss/omega-xirBss*hrBss+wBss*phipB*lrBss)/(x*n*aBss/omega-(1-xirBss)*RBss*aBss);
lamCss    = (x*n*(1-omega)*aCss/omega-xirCss*hrCss+wCss*phipC*lrCss)/(x*n*aCss/omega-(1-xirCss)*RCss*aCss);
arAss     = lamAss*aAss;
arBss     = lamBss*aBss;
arCss     = lamCss*aCss;
awAss     = aAss-arAss;
awBss     = aBss-arBss;
awCss     = aCss-arCss;
crAss     = xirAss*(RAss*arAss+hrAss);
crBss     = xirBss*(RBss*arBss+hrBss);
crCss     = xirCss*(RCss*arCss+hrCss);
cwAss     = xiwAss*(RAss*awAss+hwAss);
cwBss     = xiwBss*(RBss*awBss+hwBss);
cwCss     = xiwCss*(RCss*awCss+hwCss);

%------------------------------------
%	MODEL
%------------------------------------

model(linear);

% 1) 2) 3) Workers consumption
cwAss*(cwA-xiwA)/xiwAss = awAss*RAss * (RA(-1) + awA(-1)) + hwAss*hwA;
cwBss*(cwB-xiwB)/xiwBss = awBss*RBss * (RB(-1) + awB(-1)) + hwBss*hwB;
cwCss*(cwC-xiwC)/xiwCss = awCss*RCss * (RC(-1) + awC(-1)) + hwCss*hwC;

% 4) 5) 6) Retirees consumption
crAss*(crA-xirA)/xirAss = RAss*arAss*(RA(-1)+arA(-1)) + hrAss*hrA;
crBss*(crB-xirB)/xirBss = RBss*arBss*(RB(-1)+arB(-1)) + hrBss*hrB;
crCss*(crC-xirC)/xirCss = RBss*arBss*(RC(-1)+arC(-1)) + hrCss*hrC;

% 7) 8) 9) Workers MPC
xiwAss*xiwA = - (x^(rho*sigma*(nu-1)))*(betaA^sigma) * ((bigomAss*RAss)^(sigma-1)) * ((sigma-1)*(bigomA(+1)+RA) + xiwA - xiwA(+1) + rho*sigma*(1-nu)*(wA-wA(+1)));
xiwBss*xiwB = - (x^(rho*sigma*(nu-1)))*(betaB^sigma) * ((bigomBss*RBss)^(sigma-1)) * ((sigma-1)*(bigomB(+1)+RB) + xiwB - xiwB(+1) + rho*sigma*(1-nu)*(wB-wB(+1)));
xiwCss*xiwC = - (x^(rho*sigma*(nu-1)))*(betaC^sigma) * ((bigomCss*RCss)^(sigma-1)) * ((sigma-1)*(bigomC(+1)+RC) + xiwC - xiwC(+1) + rho*sigma*(1-nu)*(wC-wC(+1)));

% 10) 11) 12) Retirees MPC
xirAss*xirA = - (x^(rho*sigma*(nu-1)))*gammaA * (betaA ^ sigma) * (RAss ^ (sigma - 1)) * ((sigma-1)*RA + xirA - xirA(+1) + rho*sigma*(1-nu)*(wA-wA(+1)));
xirBss*xirB = - (x^(rho*sigma*(nu-1)))*gammaB * (betaB ^ sigma) * (RBss ^ (sigma - 1)) * ((sigma-1)*RB + xirB - xirB(+1) + rho*sigma*(1-nu)*(wB-wB(+1)));
xirCss*xirC = - (x^(rho*sigma*(nu-1)))*gammaC * (betaC ^ sigma) * (RCss ^ (sigma - 1)) * ((sigma-1)*RC + xirC - xirC(+1) + rho*sigma*(1-nu)*(wC-wC(+1)));

% 13) 14) 15) Retirees Human wealth
hrAss*hrA = wAss*phipA*lrAss*(wA+lrA) + (x*hrAss*gammaA/RAss)*(hrA(+1)-RA);
hrBss*hrB = wBss*phipB*lrBss*(wB+lrB) + (x*hrBss*gammaB/RBss)*(hrB(+1)-RB);
hrCss*hrC = wCss*phipC*lrCss*(wC+lrC) + (x*hrCss*gammaC/RCss)*(hrC(+1)-RC);

% 16) 17) 18) Workers Human wealth
hwAss*hwA = wAss*lwAss*(wA+lwA) + (x*omega*hwAss/bigomAss/RAss)*(hwA(+1)-bigomA(+1)-RA) + ((phipA^(nu-1))*(epsAss^(1/(1-sigma)))*x*(1-omega)*hrAss/psiA/RAss/bigomAss)*(epsA(+1)/(1-sigma)+hrA(+1)-RA-bigomA(+1));
hwBss*hwB = wBss*lwBss*(wB+lwB) + (x*omega*hwBss/bigomBss/RBss)*(hwB(+1)-bigomB(+1)-RB) + ((phipB^(nu-1))*(epsBss^(1/(1-sigma)))*x*(1-omega)*hrBss/psiB/RBss/bigomBss)*(epsB(+1)/(1-sigma)+hrB(+1)-RB-bigomB(+1));
hwCss*hwC = wCss*lwCss*(wC+lwC) + (x*omega*hwCss/bigomCss/RCss)*(hwC(+1)-bigomC(+1)-RC) + ((phipC^(nu-1))*(epsCss^(1/(1-sigma)))*x*(1-omega)*hrCss/psiC/RCss/bigomCss)*(epsC(+1)/(1-sigma)+hrC(+1)-RC-bigomC(+1));

% 19) 20) 21) Retirees asset
arA = lamA + aA;
arB = lamB + aB;
arC = lamC + aC;

% 22) 23) 24) Workers asset
awAss*awA = aAss*aA - lamAss*aAss*(lamA + aA);
awBss*awB = aBss*aB - lamBss*aBss*(lamB + aB);
awCss*awC = aCss*aC - lamCss*aCss*(lamC + aC);

% 25) 26) 27) 28) 29) 30) Adjustment factor & Ratio of MPC
epsA = xirA - xiwA;
epsB = xirB - xiwB;
epsC = xirC - xiwC;
bigomAss*bigomA = (1 - omega) * (epsAss ^ (1 / (1 - sigma)))*(phipA^(nu-1))*((1 / (1 - sigma))*epsA);
bigomBss*bigomB = (1 - omega) * (epsBss ^ (1 / (1 - sigma)))*(phipB^(nu-1))*((1 / (1 - sigma))*epsB);
bigomCss*bigomC = (1 - omega) * (epsCss ^ (1 / (1 - sigma)))*(phipC^(nu-1))*((1 / (1 - sigma))*epsC);

% 31) 32) 33) Distribution of wealth
x*n*(omega-1)*aAss*aA/omega + x*n*lamAss*aAss*(aA+lamA)/omega = lamAss*RAss*aAss*(lamA(-1)+RA(-1)+aA(-1)) - xirAss*lamAss*RAss*aAss*(xirA+lamA(-1)+RA(-1)+aA(-1))-xirAss*hrAss*(xirA+hrA) + wAss*phipA*lrAss*(wA+lrA);
x*n*(omega-1)*aBss*aB/omega + x*n*lamBss*aBss*(aB+lamB)/omega = lamBss*RBss*aBss*(lamB(-1)+RB(-1)+aB(-1)) - xirBss*lamBss*RBss*aBss*(xirB+lamB(-1)+RB(-1)+aB(-1))-xirBss*hrBss*(xirB+hrB) + wBss*phipB*lrBss*(wB+lrB);
x*n*(omega-1)*aCss*aC/omega + x*n*lamCss*aCss*(aC+lamC)/omega = lamCss*RCss*aCss*(lamC(-1)+RC(-1)+aC(-1)) - xirCss*lamCss*RCss*aCss*(xirC+lamC(-1)+RC(-1)+aC(-1))-xirCss*hrCss*(xirC+hrC) + wCss*phipC*lrCss*(wC+lrC);

% 34) 35) 36) 37) 38) No arbitrage conditions
RAss*pFAss*(RA+pFA) = x*n*pFAss*pFA(+1) + x*n*dFAss*dFA(+1);
RBss*pFBss*(RB+pFB) = x*n*pFBss*pFB(+1) + x*n*dFBss*dFB(+1);
RCss*pFCss*(RC+pFC) = x*n*pFCss*pFC(+1) + x*n*dFCss*dFC(+1);
RA = RB+eB(+1)-(eB);
RA = RC+eC(+1)-(eC);

% 39-41 Retirees labor
lrAss*lrA = -((1-nu)*crAss/nu/phipA/wAss)*(crA - wA);
lrBss*lrB = -((1-nu)*crBss/nu/phipB/wBss)*(crB - wB);
lrCss*lrC = -((1-nu)*crCss/nu/phipC/wCss)*(crC - wC);

% 42-44 Workers labor
lwAss*lwA = -((1-nu)*cwAss/nu/wAss)*(cwA - wA);
lwBss*lwB = -((1-nu)*cwBss/nu/wBss)*(cwB - wB);
lwCss*lwC = -((1-nu)*cwCss/nu/wCss)*(cwC - wC);

% 45-47 Aggregate consumption
cAss*cA = crAss*crA + cwAss*cwA;
cBss*cB = crBss*crB + cwBss*cwB;
cCss*cC = crCss*crC + cwCss*cwC;

% 48-50 Aggregate asset
aAss*aA = kAss*kA + pFAss*pFA + fA;                              % fA is loglinearization of (1+FA)
aBss*aB = kBss*kB + pFBss*pFB + fB;                              % fB is loglinearization of (1+FB)
aCss*aC = kCss*kC + pFCss*pFC + fC;                              % fC is loglinearization of (1+FC)

% 51-59 Consumption Allocation
cAA = -eta*(paA) + cA;
cBB = -eta*(pbB) + cB;
cCC = -eta*(pcC) + cC;
cBA = -eta*(pbA) + cA;
cCA = -eta*(pcA) + cA;
cAB = -eta*(paB) + cB;
cCB = -eta*(pcB) + cB;
cAC = -eta*(paC) + cC;
cBC = -eta*(pbC) + cC;

% 60-62 CPI
0 = (1-phi)*paA + phi*pbA/2 + phi*pcA/2;
0 = (1-phi)*pbB + phi*paB/2 + phi*pcB/2;
0 = (1-phi)*pcC + phi*pbC/2 + phi*paC/2;

% 63-68 Law of one price
paA = eB+paB;
paA = eC+paC;
pbA = eB+pbB;
pbA = eC+pbC;
pcA = eB+pcB;
pcA = eC+pcC;

% 69-71 Real wage
wA = paA + mcA + yAA - lA;
wB = pbB + mcB + yBB - lB;
wC = pcC + mcC + yCC - lC;

% 72-74 Rental rate
RAss*(RA+QA) = (1-delta)*QA(+1) + ((alpha)*mcAss*yAAss/kAss)*(mcA(+1) + paA(+1) + yAA(+1) - kA);
RBss*(RB+QB) = (1-delta)*QB(+1) + ((alpha)*mcBss*yBBss/kBss)*(mcB(+1) + pbB(+1) + yBB(+1) - kB);
RCss*(RC+QC) = (1-delta)*QC(+1) + ((alpha)*mcCss*yCCss/kCss)*(mcC(+1) + pcC(+1) + yCC(+1) - kC);

% 75-77 Real Marginal Cost / Production function
yAA = (1-alpha)*lA + alpha*kA(-1);
yBB = (1-alpha)*lB + alpha*kB(-1);
yCC = (1-alpha)*lC + alpha*kC(-1);

% 78-83 PC
0 = kappa*mcAss*mcA - gammap*infpA + x*n*gammap*infpA(+1)/RAss;
0 = kappa*mcBss*mcB - gammap*infpB + x*n*gammap*infpB(+1)/RBss;
0 = kappa*mcCss*mcC - gammap*infpC + x*n*gammap*infpC(+1)/RCss;
infpA = infA+paA-paA(-1);
infpB = infB+pbB-pbB(-1);
infpC = infC+pcC-pcC(-1);

% 84-86 Monetary Policy
RnA = rhoi*RnA(-1) + (1-rhoi)*pipi*infA + e_mA;  
RnB = rhoi*RnB(-1) + (1-rhoi)*pipi*infB + e_mB;  
RnC = rhoi*RnC(-1) + (1-rhoi)*pipi*infC + e_mC; 

% 87-89 Fisher eq
RA = RnA - infA(+1);
RB = RnB - infB(+1);
RC = RnC - infC(+1);

% 90-95 Capital accumulation and Price of Capital
n*x*kAss*kA = (1-delta)*kAss*kA(-1) + invAss*invA - 0.5*zeta*n*x*n*x*invAss*(3*invA-2*invA(-1)) - 0.5*zeta*n*x*n*x*invAss*invA + zeta*n*x*n*x*invAss*(2*invA-invA(-1));
n*x*kBss*kB = (1-delta)*kBss*kB(-1) + invBss*invB - 0.5*zeta*n*x*n*x*invBss*(3*invB-2*invB(-1)) - 0.5*zeta*n*x*n*x*invBss*invB + zeta*n*x*n*x*invBss*(2*invB-invB(-1));
n*x*kCss*kC = (1-delta)*kCss*kC(-1) + invCss*invC - 0.5*zeta*n*x*n*x*invCss*(3*invC-2*invC(-1)) - 0.5*zeta*n*x*n*x*invCss*invC + zeta*n*x*n*x*invCss*(2*invC-invC(-1));

QA/(x*n*x*n*zeta) - 0.5*(QA+2*invA-2*invA(-1)) - 0.5*QA + (QA+invA-invA(-1)) - (QA+2*invA-2*invA(-1)) + (QA+invA-invA(-1)) = -x*n*(QA(+1)+3*invA(+1)-3*invA-RA)/RAss + x*n*(QA(+1)+2*invA(+1)-2*invA-RA)/RAss;
QB/(x*n*x*n*zeta) - 0.5*(QB+2*invB-2*invB(-1)) - 0.5*QB + (QB+invB-invB(-1)) - (QB+2*invB-2*invB(-1)) + (QB+invB-invB(-1)) = -x*n*(QB(+1)+3*invB(+1)-3*invB-RB)/RBss + x*n*(QB(+1)+2*invB(+1)-2*invB-RB)/RBss;
QC/(x*n*x*n*zeta) - 0.5*(QC+2*invC-2*invC(-1)) - 0.5*QC + (QC+invC-invC(-1)) - (QC+2*invC-2*invC(-1)) + (QC+invC-invC(-1)) = -x*n*(QC(+1)+3*invC(+1)-3*invC-RC)/RCss + x*n*(QC(+1)+2*invC(+1)-2*invC-RC)/RCss;

% 96-98 Resource constraint
yAAss*yAA = cAAss*cAA + cABss*cAB + cACss*cAC + invAss*invA;
yBBss*yBB = cBBss*cBB + cBAss*cBA + cBCss*cBC + invBss*invB;
yCCss*yCC = cCCss*cCC + cCAss*cCA + cCBss*cCB + invCss*invC;

% 99-101 Dividend
dFAss*dFA = yAAss*yAA - mcAss*yAAss*(mcA+yAA);
dFBss*dFB = yBBss*yBB - mcBss*yBBss*(mcB+yBB);
dFCss*dFC = yCCss*yCC - mcCss*yCCss*(mcC+yCC);

% 102-104 Foreign asset
x*n*fA = RAss*fA(-1) + cABss*(paA+cAB) + cACss*(paA+cAC) - cBAss*(pbA+cBA) - cCAss*(pcA+cCA);
x*n*fB = RBss*fB(-1) + cBAss*(pbB+cBA) + cBCss*(pbB+cBC) - cABss*(paB+cAB) - cCBss*(pcB+cCB);
fA + fB + fC = 0;

% 117) 118) 119) Aggregate labor
lAss*lA = lwAss*lwA + phipA*lrAss*lrA;
lBss*lB = lwBss*lwB + phipB*lrBss*lrB;
lCss*lC = lwCss*lwC + phipC*lrCss*lrC;

% Income

(cAss + aAss)*aggiA = cAss*cA + aAss*aA; 
(cBss + aBss)*aggiB = cBss*cB + aBss*aB; 
(cCss + aCss)*aggiC = cCss*cC + aCss*aC; 
(cwAss + awAss)*wiA = cwAss*cwA + awAss*awA; 
(cwBss + awBss)*wiB = cwBss*cwB + awBss*awB; 
(cwCss + awCss)*wiC = cwCss*cwC + awCss*awC; 
(crAss + arAss)*riA = crAss*crA + arAss*arA; 
(crBss + arBss)*riB = crBss*crB + arBss*arB;
(crCss + arCss)*riC = crCss*crC + arCss*arC;

(cABss+cACss)*expA = cABss*(paA+cAB) + cACss*(paA+cAC);
(cBAss+cBCss)*expB = cBAss*(pbB+cBA) + cBCss*(pbB+cBC);
(cCAss+cCBss)*expC = cCAss*(pcC+cBA) + cCBss*(pcC+cBC);
(cBAss+cCAss)*impA = cBAss*(pbA+cBA) + cCAss*(pcA+cCA);
(cABss+cCBss)*impB = cABss*(paB+cAB) + cCBss*(pcB+cCB);
(cACss+cBCss)*impC = cACss*(paC+cAC) + cBCss*(pbC+cBC);

cBAss*(imppA+cBA+pbA)+cCAss*(imppA+cCA+pcA) = cBAss*(2*pbA+cBA) + cCAss*(2*pcA+cCA);
cABss*(imppB+cAB+paB)+cCBss*(imppB+cCB+pcB) = cABss*(2*paB+cAB) + cCBss*(2*pcB+cCB);
cBCss*(imppC+cBC+pbC)+cACss*(imppC+cAC+paC) = cBCss*(2*pbC+cBC) + cACss*(2*paC+cAC);
end;

steady;
check;

shocks;
var e_mA;
periods 1;
values 0.0025;
var e_mB;
periods 1;
values 7.5000e-04;
var e_mC;
periods 1;
values 7.5000e-04;
end;

perfect_foresight_setup(periods=100);
perfect_foresight_solver;


